==> virtuoso-opensource_7.2.5.1+dfsg1.orig.tar.xz: virtuoso-opensource-7.2.5.1/CREDITS.md <==
Credits
=======

*Copyright (C) 1998-2018 OpenLink Software <vos.admin@openlinksw.com>*


Included Functionality
----------------------

The OpenLink Software Virtuoso Open-Source Edition (VOS) project wishes to
acknowledge incorporation of code from the following projects:

OpenSSL
<http://www.openssl.org/>

    This product includes software developed by the OpenSSL Project for use
    in the OpenSSL Toolkit.

    This product includes cryptographic software written by Eric Young
    (eay@cryptsoft.com).

    This product includes software written by Tim Hudson
    (tjh@cryptsoft.com)

    OpenSSL is distributed under the terms of the OpenSSL License:
    <http://www.openssl.org/source/license.html>

    As cryptographic software, OpenSSL may be subject to export
    restrictions: <http://www.openssl.org/support/faq.html#LEGAL1>


Tidy-html5 - HTML parser and pretty printer
<http://www.htacg.org/tidy-html5/>

    This product includes tidy-html5 which is currently maintained by HTACG:
    <http://www.html-tidy.org/#acknowledgements>

    Tidy-html5 is distributed under the terms of the W3C License:
    <https://github.com/htacg/tidy-html5/blob/4.9.26/LICENSE.txt>


Zlib - compression library
<http://www.zlib.net/>

    This product includes the Zlib library developed by Jean-loup Gailly
    and Mark Adler.

    Zlib is distributed under the terms of the Zlib/PNG license:
    <http://opensource.org/licenses/zlib-license.php>


PCRE
<http://www.pcre.org/>

    This product includes the Perl-Compatible Regular-Expression Library
    (PCRE) by Phillip Hazel.

    PCRE is distributed under the terms of the BSD license:
    <http://www.pcre.org/license.txt>


OAT
<http://sourceforge.net/projects/oat/>

    Virtuoso uses the OpenLink AJAX Toolkit (OAT) in the Data Space
    application suite.

    OAT is distributed under the terms of the GNU Public License v2:
    <http://www.gnu.org/copyleft/gpl.html>


CKEditor
<http://ckeditor.com/>

    Virtuoso uses the CKEditor, a WYSIWYG editor in javascript in the
    Data Space application suite.

    CKEditor is distributed under the terms of the GNU Public License,
    the Lesser GNU Public License or the Mozilla Public License:
    <http://ckeditor.com/license>


SHA1 Javascript

    Virtuoso uses a Javsscript implementation of the Secure Hash Algoritm
    (SHA1) as defined in FIPS PUB 180-1, written  by Paul Johnston

    SHA1 is distributed under the terms of the BSD license
    <http://pajhome.org.uk/crypt/md5>


MD5 Java

    Virtuoso uses a Java implementation of the MD5 hash algorithm
    as defined in RFC1231, written Santeri Paavolainen

    MD5.java is distributed under the terms of the GNU Lesser General
    Public License (LGPL): <http://www.gnu.org/licenses/lgpl.html>.


DocBook stylesheets
<http://sourceforge.net/projects/docbook/>

    Virtuoso uses the DocBook stylesheets to generate HTML based documentation.

    DocBook is distributable under the terms of the MIT/X Consortium License.


Optional functionality
----------------------
OpenLink Software Virtuoso Open-Source Edition contains optional
functionality that may require libraries from some of the following
projects:


Perl
<http://www.perl.com/>

    Virtuoso may be linked against libperl.so to provide a Perl hosting
    environment.

    Perl is distributed under the terms of the Artistic License:
    <http://www.perl.com/language/misc/Artistic.html>


Python
<http://www.python.org>

    Virtuoso may be linked against libpython.so to provide a Python hosting
    environment.

    Python is distributed under the terms of the Python License:
    <http://www.python.org/psf/license/>


Ruby
<http://www.ruby-lang.org/>

    Virtuoso may be linked against libruby.so to provide a Ruby hosting
    environment.

    Ruby is distributed under the terms of the Ruby License:
    <http://www.ruby-lang.org/en/about/license.txt>


PHP
<http://www.php.net/>

    Virtuoso may be linked against libphp5.so to provide a PHP hosting
    environment.

    PHP is distributed under the terms of the PHP License:
    <http://php.net/license/>


Java
<http://www.java.com/>

    Virtuoso may be linked against libjvm.so to provide a Java hosting
    environment.

    Use of this module requires a JVM to be installed such as one from
    <http://www.java.com/>


Readline
<http://directory.fsf.org/readline.html>

    Virtuoso Open-Source Edition may be compiled against the readline
    library.

    Readline is distributed under the terms of the GNU Public License
    version 2 or later:
    <http://www.gnu.org/licenses/info/GPLv2orLater.html>

    This library is not present in OpenLink Virtuoso (commercial edition).


OpenLDAP
<http://www.openldap.org/>

    Virtuoso may be linked against OpenLdap to provide dynamic
    authentication lookups against existing LDAP servers.

    OpenLDAP is distributed under the terms of the OpenLDAP Public License:
    <http://www.openldap.org/software/release/license.html>


GTK+
<http://www.gtk.org/>

    Parts of Virtuoso may be linked against the Gimp Toolkit graphical
    library (GTK+).

    GTK+ is distributed under the terms of the GNU Lesser General Public
    License (LGPL): <http://www.gnu.org/licenses/lgpl.html>.


iODBC
<http://www.iodbc.org/>

    Virtuoso may be linked against the iODBC driver manager library.

    iODBC is distributed under the terms of either the LGPL or BSD license:
    <http://www.iodbc.org/index.php?page=docs/license>


WBXML2
<http://libwbxml.aymerick.com>

    Parts of Virtuoso may be linked against the WBXML2 library.

    WBXML2 is distributed under the terms of the GNU Lesser General Public
    License (LGPL): <http://www.gnu.org/licenses/lgpl.html>.


Handle System Client Library
<http://handle.net>

   Parts of Virtuoso may be linked against the Handle System Client library.

   The Handle System Client Library is distributed under the terms of
   the Handle.NET Software Client Library (VER. 5) -- C Version License:
   <http://hdl.handle.net/4263537/5027>


Rendezvous
<http://www.opensource.apple.com/projects/rendezvous/>

    Virtuoso may be linked against the Rendezvous network-discovery
    library by Apple Computer, Inc.

    Rendezvous is distributed under the terms of the Apple Public Source
    License: <http://www.opensource.apple.com/apsl/>


ImageMagick
<http://www.imagemagick.org/>

   Parts of Virtuoso may be linked against the ImageMagick graphics library.

   ImageMagick is distributed under the terms of the ImageMagick license:
   <http://www.imagemagick.org/script/license.php> which is compatible
   with GPL.

==> virtuoso-opensource_7.2.12+dfsg.orig.tar.xz: virtuoso-opensource-7.2.12/CREDITS.md <==
Credits
=======

*Copyright (C) 1998-2024 OpenLink Software <vos.admin@openlinksw.com>*


Included Functionality
----------------------

The OpenLink Software Virtuoso Open-Source Edition (VOS) project wishes to
acknowledge incorporation of code from the following projects:

OpenSSL
<http://www.openssl.org/>

    This product includes software developed by the OpenSSL Project for use
    in the OpenSSL Toolkit.

    This product includes cryptographic software written by Eric Young
    (eay@cryptsoft.com).

    This product includes software written by Tim Hudson
    (tjh@cryptsoft.com)

    OpenSSL is distributed under the terms of the OpenSSL License:
    <http://www.openssl.org/source/license.html>

    As cryptographic software, OpenSSL may be subject to export
    restrictions: <http://www.openssl.org/support/faq.html#LEGAL1>


Tidy-html5 - HTML parser and pretty printer
<http://www.htacg.org/tidy-html5/>

    This product includes tidy-html5 which is currently maintained by HTACG:
    <http://www.html-tidy.org/#acknowledgements>

    Tidy-html5 is distributed under the terms of the W3C License:
    <https://github.com/htacg/tidy-html5/blob/4.9.26/LICENSE.txt>


Zlib - compression library
<http://www.zlib.net/>

    This product includes the Zlib library developed by Jean-loup Gailly
    and Mark Adler.

    Zlib is distributed under the terms of the Zlib/PNG license:
    <http://opensource.org/licenses/zlib-license.php>


PCRE
<http://www.pcre.org/>

    This product includes the Perl-Compatible Regular-Expression Library
    (PCRE) by Phillip Hazel.

    PCRE is distributed under the terms of the BSD license:
    <http://www.pcre.org/license.txt>


OAT
<http://sourceforge.net/projects/oat/>

    Virtuoso uses the OpenLink AJAX Toolkit (OAT) in the Data Space
    application suite.

    OAT is distributed under the terms of the GNU Public License v2:
    <http://www.gnu.org/copyleft/gpl.html>


CKEditor
<http://ckeditor.com/>

    Virtuoso uses the CKEditor, a WYSIWYG editor in javascript in the
    Data Space application suite.

    CKEditor is distributed under the terms of the GNU Public License,
    the Lesser GNU Public License or the Mozilla Public License:
    <http://ckeditor.com/license>


SHA1 Javascript

    Virtuoso uses a Javsscript implementation of the Secure Hash Algoritm
    (SHA1) as defined in FIPS PUB 180-1, written  by Paul Johnston

    SHA1 is distributed under the terms of the BSD license
    <http://pajhome.org.uk/crypt/md5>


MD5 Java

    Virtuoso uses a Java implementation of the MD5 hash algorithm
    as defined in RFC1231, written Santeri Paavolainen

    MD5.java is distributed under the terms of the GNU Lesser General
    Public License (LGPL): <http://www.gnu.org/licenses/lgpl.html>.


MS5 C
<http://openwall.info/wiki/people/solar/software/public-domain-source-code/md5>

    Virtuoso uses a C implementation of an OpenSSL-compatible MD5
    hash algorithm as defined in RDF1231, written by Alexander
    Peslyak aka Solar Designer

    md5.c and md5.h have been placed in the public domain.
    There is absolutely no warranty.


DocBook stylesheets
<http://sourceforge.net/projects/docbook/>

    Virtuoso uses the DocBook stylesheets to generate HTML based documentation.

    DocBook is distributable under the terms of the MIT/X Consortium License.


Optional functionality
----------------------
OpenLink Software Virtuoso Open-Source Edition contains optional
functionality that may require libraries from some of the following
projects:


Perl
<http://www.perl.com/>

    Virtuoso may be linked against libperl.so to provide a Perl hosting
    environment.

    Perl is distributed under the terms of the Artistic License:
    <http://www.perl.com/language/misc/Artistic.html>


Python
<http://www.python.org>

    Virtuoso may be linked against libpython.so to provide a Python hosting
    environment.

    Python is distributed under the terms of the Python License:
    <http://www.python.org/psf/license/>


Ruby
<http://www.ruby-lang.org/>

    Virtuoso may be linked against libruby.so to provide a Ruby hosting
    environment.

    Ruby is distributed under the terms of the Ruby License:
    <http://www.ruby-lang.org/en/about/license.txt>


PHP
<http://www.php.net/>

    Virtuoso may be linked against libphp5.so to provide a PHP hosting
    environment.

    PHP is distributed under the terms of the PHP License:
    <http://php.net/license/>


Java
<http://www.java.com/>

    Virtuoso may be linked against libjvm.so to provide a Java hosting
    environment.

    Use of this module requires a JVM to be installed such as one from
    <http://www.java.com/>


Readline
<http://directory.fsf.org/readline.html>

    Virtuoso Open-Source Edition may be compiled against the readline
    library.

    Readline is distributed under the terms of the GNU Public License
    version 2 or later:
    <http://www.gnu.org/licenses/info/GPLv2orLater.html>

    This library is not present in OpenLink Virtuoso (commercial edition).


OpenLDAP
<http://www.openldap.org/>

    Virtuoso may be linked against OpenLdap to provide dynamic
    authentication lookups against existing LDAP servers.

    OpenLDAP is distributed under the terms of the OpenLDAP Public License:
    <http://www.openldap.org/software/release/license.html>


GTK+
<http://www.gtk.org/>

    Parts of Virtuoso may be linked against the Gimp Toolkit graphical
    library (GTK+).

    GTK+ is distributed under the terms of the GNU Lesser General Public
    License (LGPL): <http://www.gnu.org/licenses/lgpl.html>.


iODBC
<http://www.iodbc.org/>

    Virtuoso may be linked against the iODBC driver manager library.

    iODBC is distributed under the terms of either the LGPL or BSD license:
    <http://www.iodbc.org/index.php?page=docs/license>


WBXML2
<http://libwbxml.aymerick.com>

    Parts of Virtuoso may be linked against the WBXML2 library.

    WBXML2 is distributed under the terms of the GNU Lesser General Public
    License (LGPL): <http://www.gnu.org/licenses/lgpl.html>.


Handle System Client Library
<http://handle.net>

   Parts of Virtuoso may be linked against the Handle System Client library.

   The Handle System Client Library is distributed under the terms of
   the Handle.NET Software Client Library (VER. 5) -- C Version License:
   <http://hdl.handle.net/4263537/5027>


Rendezvous
<http://www.opensource.apple.com/projects/rendezvous/>

    Virtuoso may be linked against the Rendezvous network-discovery
    library by Apple Computer, Inc.

    Rendezvous is distributed under the terms of the Apple Public Source
    License: <http://www.opensource.apple.com/apsl/>


ImageMagick
<http://www.imagemagick.org/>

   Parts of Virtuoso may be linked against the ImageMagick graphics library.

   ImageMagick is distributed under the terms of the ImageMagick license:
   <http://www.imagemagick.org/script/license.php> which is compatible
   with GPL.
